body {
    font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
}

#form {
    float: right;
    font-size: 8pt;
}

#searchform {
    margin-top: 7px;
    margin-bottom: 7px;
    padding-bottom: 7px;
    border-bottom: 1px solid #bbf;
}

.file-list {
    list-style-type: none;
    text-align: center;
    margin: 0;
    padding: 0;
    overflow: auto;
}

.file-list li {
    float: left;
    padding: 1px;
    border: 1px solid #888;
    margin: 2px;
    background: #666;
}

.file-list div {
    width: 100px;
    height: 100px;
    display: table-cell;
    vertical-align: middle;
    cursor: pointer;
}

.file-list img {
    display: block;
    margin: auto;
}

#sizes {
    left: 255px;
    width: 300px;
    padding: 10px;
    display: none;
    position: absolute;
    border: 2px solid #fff;
    background: #ddd;
}

.pagination {
    display: inline-block;
    padding-left: 0;
    margin: 20px 0;
    border-radius: 4px;
}

.pagination > li {
    display: inline;
}

.pagination > li > a,
.pagination > li > span {
    position: relative;
    float: left;
    padding: 6px 12px;
    margin-left: -1px;
    line-height: 1.42857143;
    color: #5b80b2;
    text-decoration: none;
    background-color: #fff;
    border: 1px solid #ddd;
}

.pagination > li:first-child > a,
.pagination > li:first-child > span {
    margin-left: 0;
    border-top-left-radius: 4px;
    border-bottom-left-radius: 4px;
}

.pagination > li:last-child > a,
.pagination > li:last-child > span {
    border-top-right-radius: 4px;
    border-bottom-right-radius: 4px;
}

.pagination > li > a:hover,
.pagination > li > span:hover,
.pagination > li > a:focus,
.pagination > li > span:focus {
    color: #23527c;
    background-color: #eee;
    border-color: #ddd;
}

.pagination > .active > a,
.pagination > .active > span,
.pagination > .active > a:hover,
.pagination > .active > span:hover,
.pagination > .active > a:focus,
.pagination > .active > span:focus {
    z-index: 2;
    color: #fff;
    cursor: default;
    background-color: #5b80b2;
    border-color: #5b80b2;
}

.pagination > .disabled > span,
.pagination > .disabled > span:hover,
.pagination > .disabled > span:focus,
.pagination > .disabled > a,
.pagination > .disabled > a:hover,
.pagination > .disabled > a:focus {
    color: #777;
    cursor: not-allowed;
    background-color: #fff;
    border-color: #ddd;
}
